# Git Brancher and Committer

This is a simple-minded, tiny package that just creates abstracting functions
for creating new branches for a repo and submodules, as well as committing
changes automatically in python.

```
pip install giter
```